package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$"`0`````````````"`!0````!`8`2$````#0``0.(```````T`"``
M"``H`!\`'@````8````T`8``-`&``#0```$````!``````0````$`````P``
M`30!@`$T`8`!-````!<````7````!`````$````!``````&````!@`````"1
MP```D<`````%``$```````$``/Z$`8'^A`&!_H0```*$```(``````8``0``
M`````@``_Q`!@?\0`8'_$````.````#@````!@````0````$```!3`&``4P!
M@`%,````+````"P````$````!&1TY5```(G<`8")W`&`B=P```#T````]```
M``0````$9'3E4@``_H0!@?Z$`8'^A````7P```%\````!`````$O=7-R+VQI
M8F5X96,O;&0N96QF7W-O```````'````!`````%.971"4T0``#6DZ0`````$
M````!`````-085@``````````$,```!A`````````#T```!'````&@```"L`
M```L````5P```!X`````````$````$\```!-````!P```#4`````````$0``
M`%\````V````%````#D``````````````#@```!4````+@```$`````G````
M4@```%$```!9````6````````````````````$H```!%```````````````P
M````5@````````!&````&`````0`````````7````$0````W````!0```#\`
M```Q````"0`````````*````#0````````!:`````````%,```!#````````
M`$X````9````8````%T````5````6P``````````````````````````````
M```````````````````````````````````````````+````````````````
M```````````````!`````````````````````````````````````````!<`
M``````````````X````<````$@```!8````=```````````````(````````
M`"$``````````````"`````E`````@```"8````M````````````````````
M```````````J````#P```#(```````````````,````C````,P``````````
M````#```````````````.@```#X````[``````````8```!!`````````!\`
M```O````20```!,````\````&P```$(`````````2````#0````H````4```
M```````I````)````````````````````$P```!+`````````"(`````````
M50```%X````````````````````````#-0&`0Q0```)L$@``"@```;@`````
M`````!(```````"H`8(!&`````$1```;```!J@``````````$@```````%T`
M`````````!(````````,```````````2```````"N@``````````$@``````
M`(T``````````!(```````%K```````````2```````#.@&`(X@````X$@``
M"@```>X``````````!(```````!^`8!*L``````2```+```!W0``````````
M$@```````7<``````````!(```````(6```````````2```````!]0``````
M````$@```````CP``````````!(```````+(`8(!``````01```9```"F0``
M````````$@```````/X``````````!(```````'````````````2````````
M8P``````````$@```````U4!@!P8````$!(```H```"$```````````2````
M```!$0``````````$@```````!0``````````!(````````V```````````2
M```````"TP&"`0@````$$0``&@```=(``````````!(```````-F`8`CP```
M`1@2```*````X0``````````$@```````W@!@"38```'J!(```H```/P`8`1
M[``````2```)```"J```````````$@```````AP``````````!(```````+@
M```````````2````````(@``````````$@```````X4!@!O@````.!(```H`
M``##```````````6````````U@``````````$@```````2H``````````!(`
M``````.-`8`2$````!P2```*````+P``````````$@```````EL`````````
M`"(```````"U```````````2```````#E0&`(M0```"T$@``"@```Z,!@"R`
M```":!(```H```.Y`8`^@````902```*```!30&!_I@````3$0``$@```NT`
M`````````!(```````/$`8(!!`````01```9````F@``````````$@``````
M`XX!@!(0````'!(```H```(W`8(!(````0@1```;````Z@&"`1`````$$0``
M&@```\X!@![<````.!(```H```$8`8("*````"`1```;```!7```````````
M$@```````(X``````````!(```````+W```````````2```````"<P``````
M````(@```````@T``````````!(```````/;`8(!"``````0```:````*0``
M````````$@```````^<!@@:$`````!```!L```$%```````````2```````!
M2```````````$@```````$X``````````!(````````<```````````2````
M````/@&`2$``````$@```````^T!@#X0````<!(```H```'\`8!(4``````2
M```````#]@&`'Q0```&,$@``"@```<P``````````!(```````0"`8`@H```
M`C02```*```"_P``````````$@```````3H``````````!(```````!Y````
M```````2```````$#P&"`0@`````$```&0``!!8!@!PH```"M!(```H```&7
M`8!(H``````2```````$(P&`0!0```&@$@``"@```&H``````````!(`````
M``,&```````````2```````!C```````````$@```````Q$``````````!(`
M``````,8```````````2```````"(0``````````$@```````^@!@@:$````
M`!```!L```"3```````````2````````=```````````$@```````C``````
M`````!(```````,D```````````2```````$+0&`+N@```"X$@``"@```BD`
M`````````!(```````#R```````````2`````&QI8G!E<FPN<V\`<F5A;&QO
M8P!M96UM;W9E`')M9&ER`'-T<G-T<@!C;&]S90!S=')C:'(`<W1R;F-M<`!B
M;V]T7T1Y;F%,;V%D97(`<&5R;%]C;VYS=')U8W0`86)O<G0`=6YL:6YK`%]?
M;'-T870U,`!P97)L7V9R964`7V9I;FD`7U]S=&%T-3``7V5X:70`;65M8W!Y
M`'!E<FQ?9&5S=')U8W0`4$Q?9&]?=6YD=6UP`%!E<FQ?<W9?<V5T<'8`4$Q?
M8W5R<F5N=%]C;VYT97AT`'!E<FQ?86QL;V,`8VQO<V5D:7(`96YV:7)O;@!?
M7V]P96YD:7(S,`!M96US970`4&5R;%]S869E<WES;6%L;&]C`%]?<W1A8VM?
M8VAK7V=U87)D`%!E<FQ?9W9?9F5T8VAP=@!?7W-P<FEN=&9?8VAK`')E860`
M4$Q?;65M;W)Y7W=R87``4&5R;%]S>7-?:6YI=#,`4&5R;%]G971?<W8`4&5R
M;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]N97=84P!097)L7V%T9F]R:U]U;FQO
M8VL`4&5R;%]S>7-?=&5R;0!?7V5R<FYO`%!E<FQ?;6=?<V5T`&UK9&ER`'!E
M<FQ?<&%R<V4`4&5R;%]N97=84U]F;&%G<P!A8V-E<W,`9V5T<&ED`%!E<FQ?
M871F;W)K7VQO8VL`<&5R;%]R=6X`;'-E96L`;W!E;@!S<')I;G1F`&=E='5I
M9`!S=')L96X`7U]S1@!S=')C;7``;&EB;2YS;RXP`&QI8F-R>7!T+G-O+C$`
M7U]D97)E9VES=&5R7V9R86UE7VEN9F\`7U]R96=I<W1E<E]F<F%M95]I;F9O
M`&QI8G!T:')E860N<V\N,0!P=&AR96%D7V%T9F]R:P!S=')D=7``;&EB8RYS
M;RXQ,@!?7W-T<FYC<'E?8VAK`%]?<')O9VYA;64`7U]P<U]S=')I;F=S`%]?
M9V5T<'=U:60U,`!?7W-Y<V-A;&P`9G!R:6YT9@!A=&5X:70`7VQI8F-?:6YI
M=`!S=')T;VL`7U]R96%D9&ER,S``7U]S=&%C:U]C:&M?9F%I;`!M86EN`&=E
M=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C=7)R96YT7V5X96,`<&%R
M7W-E='5P7VQI8G!A=&@`<&%R7VUK=&UP9&ER`'AS7VEN:70`7U]S=&%R=`!P
M87)?96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?0D]/5`!S:&%?=7!D871E
M`&UY7W!A<E]P;`!P87)?8F%S96YA;64`7U]B<W-?<W1A<G0`7U]E;F0`<VAA
M7VEN:70`<&%R7V1I<FYA;64`<&%R7VEN:71?96YV`%]E9&%T80!P87)?9FEN
M9'!R;V<`<VAA7V9I;F%L`'!A<E]C;&5A;G5P`"]U<W(O<&MG+VQI8B]P97)L
M-2\U+C,X+C`O<&]W97)P8RUN971B<V0M=&AR96%D+6UU;'1I+T-/4D4Z+W5S
M<B]P:V<O;&EB``````&!_O@``#T!``````&!_PP``"P!``````&!__```"=)
M``````&!_I@``#$3``````&"`1@```,3``````&"`2```#83``````&"`B@`
M`#D3``````&"``````(5``````&"``0```05``````&"``@```45``````&"
M``P```85``````&"`!````<5``````&"`!0```@5``````&"`!@```D5````
M``&"`!P```L5``````&"`"````T5``````&"`"0```X5``````&"`"@```\5
M``````&"`"P``!`5``````&"`#```!$5``````&"`#0``!,5``````&"`#@`
M`!05``````&"`#P``!45``````&"`$```!85``````&"`$0``!@5``````&"
M`$@``!D5``````&"`$P``!H5``````&"`%```!L5``````&"`%0``!T5````
M``&"`%@``!\5``````&"`%P``"(5``````&"`&```",5``````&"`&0``"05
M``````&"`&@``"45``````&"`&P``"@5``````&"`'```"D5``````&"`'0`
M`"L5``````&"`'@``"P5``````&"`'P``"T5``````&"`(```#(5``````&"
M`(0``#05``````&"`(@``#H5``````&"`(P``#L5``````&"`)```#P5````
M``&"`)0``#T5``````&"`)@``#X5``````&"`)P``$`5``````&"`*```$(5
M``````&"`*0``$,5``````&"`*@``$05``````&"`*P``$45``````&"`+``
M`$85``````&"`+0``$@5``````&"`+@``$H5``````&"`+P``$P5``````&"
M`,```$T5``````&"`,0``$X5``````&"`,@``%$5``````&"`,P``%,5````
M``&"`-```%05``````&"`-0``%45``````&"`-@``%85``````&"`-P``%<5
M``````&"`.```%@5``````&"`.0``%H5``````&"`.@``%L5``````&"`.P`
M`%P5``````&"`/```%T5``````&"`/0``%\5``````&"`/@``&`5`````'P(
M`J:0`0`$E"'_\$@`,(4X(0`0@`$`!'P(`Z9.@``@`````$*?``5]:`*F/:L`
M`CFM;NQ\XSMX?01#>$@``0V4(?_@?`@"ID*?``63P0`8?\@"IC_>``*3H0`4
M.]YL>)/A`!R#OH`$@_Z``)`!`"1_G^A`0)P`'($_```[_P`$?2D#IDZ`!"%_
MG^A`09S_[(`!`"2#H0`4@\$`&'P(`Z:#X0`<."$`($Z``""4(?_@?`@"ID*?
M``63P0`8?\@"IC_>``*3@0`0.]YL#)/A`!R#GH`,@_Z`")`!`"1_G^!`0)P`
M2(D_``>3H0`4+XD`^$&^`!1(``!0B3\`!R^)`/A`G@!$@3\`"#O_``R#O__T
M?2D#IDZ`!"%_G^!`D'T``$&<_]B#H0`4@`$`)(.!`!"#P0`8?`@#IH/A`!PX
M(0`@3H``($@`,G&4(?_@?`@"ID*?``63@0`0?)PC>9/!`!A_R`*F/]X``I`!
M`"0[WFMPDV$`#).A`!23X0`<08(!`($\``"`_H`<@4D``(-^@"`OB@``@1P`
M").'``"1&P``09X`S($>@"212```@4D``(DJ```OB0``09X`("N)`"\Y2@`!
M0)[_[)%(``")*@``+XD``$">_^@O@P``09X`"$@`-*5(`#3Q@3Z`+"^)``!!
MG@"P@_Z`$(.^@#!_G^A`0)P`'($_```[_P`$?2D#IDZ`!"%_G^A`09S_[(!^
M@#1(`#1E@_Z`%(.^@#A_G^A`0)P`'($_```[_P`$?2D#IDZ`!"%_G^A`09S_
M[(!^@#Q(`#0U2__]K8"[``"`G```@'P`!$@`+L5(`#-=@3Z`)(%>@"B120``
M2___8(#>@!@XX``3.*```CA@```X@``$3,8Q@D@`,P$X8``!2``Q24O__@U+
M__]0+`,``)0A_]"3X0`L08(!"#T@`8*380`<@VD!$"^;``!!G@#\D\$`*(DC
M```OB0``09X`W"N)`#T[P```0)X`C(/[```OGP``09X`N'P(`J:300`8D`$`
M-'R:(WB3@0`@?'P;>).A`"1_?=MX?\7S>'^$XWA_X_MX2``QM2^#``!`G@`0
M?3_PKB^)`#U!G@!<A_T`!"^?``!`GO_4@`$`-(-!`!B#80`<?`@#IH.!`""#
MH0`D@\$`*'_C^WB#X0`L."$`,$Z``"!\?AMXC3X``2Z)```KB0`]098`"$"^
M__!_P_!02___7'^[Z%`[W@`!?[T6<'__\A23N@``2___H(-A`!R#P0`H2___
ML#O```!+__\P.^```$O__Z`[X```@V$`'$O__Y24(?_0?`@"II.A`"0_H`&"
M.[T"*)`!`#23P0`H@3T``)$A`!PY(```D^$`+#_``8)\?QMX.($`&'_C^WA,
MQC&"2__^F2^#``!!G@!,@4$`&($>`1!52A`Z?2A2%(#I``0OAP``?.A1+D&^
M_\R!20`(+XH``)5)``1`GO_T.($`&'_C^WA,QC&"2__^42^#``!`GO^\@2$`
M'(%=``!]*5)Y.4```$""`""``0`T@Z$`)(/!`"A\"`.F@^$`+#@A`#!.@``@
M2``RP90A_S"3H0#$?'T;>9/A`,P_X`&"._\"*($_``"1(0"L.2```$&"`!")
M/0``+XD``$">`"B!(0"L@5\``'TI4GDY0```0((!4(.A`,2#X0#,."$`T$Z`
M`"!\"`*FDX$`P)`!`-1(`#)Y?'P;>4&"`."3(0"T/R`!@)-!`+@_0`&`DV$`
MO#]@`8"3P0#(.WM+1#M:2T@[.4M,?X/C>$@`,=$L`P``08(`N#O#``U_9-MX
M?\/S>$@`+PDO@P``0;[_W']$TWA_P_-X2``N]2^#``!!GO_(?Z/K>),!`+!(
M`#'1?'@;>'_#\WA(`#'%?'@:%#AC``)(`"\I?\;S>'QX&WA_I>MX?R3+>$S&
M,8)(`#%Q.($`$'\#PWA(`"[U+X/__W\#PWA!G@`4@2$`&%4I!"8OB4``09X`
M6$@`+L5_`\-X2``PS8,!`+!+__]0@`$`U(.!`,!\"`.F2__^W'^#XWA(`"[]
M?Z/K>$@`,$6``0#4@R$`M(-!`+A\"`.F@V$`O(.!`,"#P0#(2__^K$O__G5+
M__^L?`@"II,!`+"0`0#4DR$`M)-!`+B380"\DX$`P)/!`,A(`#$)E"'_X'P(
M`J8\P`&`/*`!@)/A`!P_X`&".___])`!`"2#___\/(`!@'__$A0XQDKD@'\`
M`#BE2$`XA$M42``P68`!`"0\X`&`@'\``#CG3B0\H`&`/(`!@(/A`!Q\YCMX
M.*4L@#B$2W`Y````?`@#IC@A`"!(`"U0E"'_L'P(`J:0`0!4DV$`/).!`$!\
M?!MXDZ$`1)/!`$@_P`&"D^$`3#O>`BB3(0`T@5X``)%!`!PY0```DT$`.(DD
M``!I*0`](2D``'_D`91_X_MX2``P*3B!`!A\>QMX?X/C>$S&,8)+__MY?'T;
M>4&"`21(`#`)?X/80$"<`/R#(0`8/T`!@E<Y$#J)/```+XD``$&>`<`KB0`]
M09X!N'^#XWA(```,*XD`/4&>`!"-(P`!+XD``$">__!\?!A0.WL``H.Z`1!\
M>QH42``M(2^#``!\?<DN09X!F(D\``"!00`8@1H!$"^)``!52A`Z?4A0+IDJ
M``!`O@`82```'(T\``$OB0``G2H``4&>``PKB0`]0)[_[#D@`#T[____F2H`
M`(T_``$OB0``G2H``4">__0X8```@2$`'(%>``!]*5)Y.4```$""`3"``0!4
M@R$`-(-!`#A\"`.F@V$`/(.!`$"#H0!$@\$`2(/A`$PX(0!03H``(#O___\[
MO?__C3\``2^)``"=/0`!0)[_]$O__Z0_0`&"DP$`,)+A`"R#&@$0@3@``"^)
M``!!G@"P?PC#>#E```!(```(?ZKK>(4H``0[J@`!+XD``$">__`Y2@`#5400
M.CU``8*!*@)T+XD``$">`%`Y(``!?(,C>)$J`G1(`"OY?'<;>4&"`&Q7N1`Z
M?P3#>'\ERWA(`"OQDOH!$#D]``$Y0```52D0.GU722Z3H0`8@N$`+(,!`#!+
M__Y<?P/#>$@`*L4O@P``?'<;>)!Z`1!!G@`@5[D0.DO__\0X8```2__^:#B`
M``@[H```2___=(+A`"R#`0`P.&#__TO__L22X0`LDP$`,$@`+@V4(?]`?`@"
MII/!`+@X@0`0D^$`O#_@`8*0`0#$._\"*'Q^&WB!/P``D2$`K#D@``!(`"U)
M+`,``$""`&2!(0`852D$)BN)0`!!G@`\;2K__R^*H`!!G@`P@2$`K(%?``!]
M*5)Y.4```$""`#R``0#$@\$`N(/A`+Q\"`.F."$`P$Z``"!_P_-X.(```D@`
M*BU\8P`T5&/9?DO__\`X8```2___N$@`+64](`&"E"'_\#DI__0\P`&`@2G_
M_#R@`8!]*1(4/(`!@(!I```XQDKD.*5(0#B$2U0X(0`02``LO)0A__`X8```
M."$`$$Z``""4(?L0?8``)CT@`8!\"`*FDZ$$Y#^@`8*3P03H.[T"*)/A!.Q\
M?AMX?)\C>#AI2X@X@0`<D`$$])-A!-R!/0``D2$$O#D@``"1@03`3,8Q@DO_
M^!U\>QMX.(``+W_#\WA(`"K)+X,``$&>`%@\8`&`?\3S>#AC2Y1,QC&"2__\
M$7_#\WB!(02\@5T``'TI4GDY0```0(("`(`!!/2!@03`@V$$W'P(`Z:#H03D
M?8"!((/!!.B#X03L."$$\$Z``""3@03@?\/S>#^``8"2H03$DT$$V#N<2Z1(
M`"PQ?X3C>'QZ&WA_X_MX2``KT7QU&WE!@@&4DL$$R"X;``"2X03,.L```),!
M!-`^X`&`DR$$U#\``8`_(`&`.UH``3KW2T0[&$Y8.SE+J&+6@``[X```B34`
M`"^)``!!G@#809(`&'ZDJWA_8]MX2``HT2^#``!!G@"(?J.K>$@`*[$Y0___
M?350KGU54A0OB0`O0)X`&)OJ```X8___C2K__R^)`"]!GO_P?'H:%"^#`_]!
MG0!D?J>K>'_)\WA_",-X?R;+>#B@!``X@```.&$`O$S&,8)(`"JI.($`(#AA
M`+Q(`"BM+X,``$">`!2!(0`H52D$)G^)L`!!G@!@?X3C>#A@``!(`"K9+X,`
M`'QU&WA`GO]$@J$$Q(+!!,B"X03,@P$$T(,A!-2#0038@X$$X$O__F!!D@`8
M?N2[>']CVWA(`"?]+X,``$&>_[1^];MX.&```4O__U0X@``!.&$`O$@`)XTO
M@P``0)[_E#Q@`8`X@0"\.&-+E$S&,8)+__HU.&$`O$@`*&F"H03$@L$$R(+A
M!,R#`030@R$$U(-!!-B#@03@2__^!(*A!,2#0038@X$$X$O__=R2H03$DL$$
MR)+A!,R3`030DR$$U)-!!-B3@03@2``J:90A__!\:AMXB2,``"^)``!!G@`@
M*XD`+SE*``%`O@`(?4-3>(DJ```OB0``0)[_Z#@A`!!.@``@E"'_X)/A`!Q\
M?QMY08(`B)/!`!B+WP``+YX``$&>`'1\"`*FD`$`)$@`*?4X8___?+\:%'^?
M*$!`G`"D?3\8KB^)`"]`G@!D?3\H4'TI`Z9(```0B24``"^)`"]`G@!,.*7_
M_T(`__`KG@`O09X`_#Q@`8`X8TY8@`$`)(/!`!B#X0`<?`@#IC@A`"!(`"=0
M@\$`&#Q@`8"#X0`<.&-+1#@A`"!(`"<X.27__WU?*%!_GTA`?4D#ID&=`+PO
MG___0+X`%$@``+"))0``+XD`+T&>`!0XI?__0@#_\'^?*$!!OO^(.27__WU?
M*%!_GTA`?4D#ID&=`(POG___0+X`%$@``("))0``+XD`+T">``PXI?__0@#_
M\'R_*%`Y)0`"*XD$`$&=`#P](`&".*4``3DI`G1_Y/MX.2D`!#C`!`!](TMX
M2``E:8`!`"2#P0`8@^$`''P(`Z8X(0`@3H``(#A@``!+___D/&`!@#AC2T1+
M__\(.2```7TI`Z9+__]8.2```7TI`Z9+__^(E"'_H'P(`J8\@`&`.*``(I`!
M`&0XA$KDDV$`3#B$``R3@0!0.&$`&).A`%0_H`&`D\$`6#_``8"3X0!</^`!
M@CO_`B@[WDO8@3\``)$A`#PY(```2``H'3Q@`8`X8TNP3,8Q@DO_]+D\8`&`
M.&-+O#N]2XA,QC&"2__TI3Q@`8`X8TO$/V`!@$S&,8)+__21/&`!@#AC2]`[
M>TOT3,8Q@DO_]'U_P_-X3,8Q@DO_]'$\8`&`.&-+Z#^``8!,QC&"2__T77^C
MZWA,QC&"2__T43N<3`!_8]MX3,8Q@DO_]$%_@^-X3,8Q@DO_]#4\8`&`.&-,
M#$S&,8)+__0E/&`!@#AC2Y1,QC&"2__T%3Q@`8`X@0`4.&-,&$S&,8)+__+9
M?&0;>4&"`!!_@^-X3,8Q@DO_]N4\8`&`.($`%#AC3"Q,QC&"2__RL7QD&WE!
M@@`4/&`!@#AC3$!,QC&"2__VN3Q@`8`X@0`4.&-,3$S&,8)+__*%?&0;>4&"
M`%Q_H^MX3,8Q@DO_]I$\@`&`?\/S>#B$3'Q,QC&"2__V?8$A`#R!7P``?2E2
M>3E```!`@@"$@`$`9(-A`$R#@0!0?`@#IH.A`%2#P0!8@^$`7#@A`&!.@``@
M/&`!@#B!`!0X8TQ<3,8Q@DO_\A%\9!MY0((`-#R``8`XH``*.(1,<#AA`"E(
M`"0A+X,``$">_X!_8]MX.($`,TS&,8)+__7]2___;']CVWA,QC&"2__U[4O_
M_UQ(`"9QE"'_T)/!`"@_P`&"@3X`_)/A`"P_X`&"+XG__SO_`BB!7P``D4$`
M'#E```!!G@`L@4$`'($?``!]2D)Y.0```'TC2WA`@@!D@\$`*(/A`"PX(0`P
M3H``(#Q@`8!\"`*F.($`&#AC2_20`0`T3,8Q@DO_\5$L`P``.2```$&"`!R)
M0P``+XH``$&>`!!I2@`P,2K__WTI41"``0`TD3X`_'P(`Z9+__^,?`@"II`!
M`#1(`"6]E"'_\'P(`J:0`0`42``EO4@`(WDL`P``08(`&(!C``"``0`4."$`
M$'P(`Z9.@``@.&```$O__^R4(?_`?`@"II/!`#@_P`&`DX$`,#O>3("3H0`T
M.($`&)/A`#P_X`&"D`$`1'Q]&W@[_P(H?\/S>($_``"1(0`<.2```$S&,8)+
M__"-?'P;>7^DZWA!@@!\B3P``"^)``!!G@!P2``B_2^#``!`O@!P?Z/K>)-A
M`"Q(`"3Y?'L;>'^#XWA(`"3M?'L:%#AC``)(`")1/,`!@#R``8!\>QMX?X?C
M>'^EZW@XQDND.(1+J$S&,8)(`"2-?V3;>'_#\WA,QC&"2__T,8-A`"Q(```0
M?\/S>$S&,8)+__0=@2$`'(%?``!]*5)Y.4```$""`"2``0!$@X$`,(.A`#1\
M"`.F@\$`.(/A`#PX(0!`3H``()-A`"Q(`"1M/`#__ST@`8`Y*4KD8`!^H'PL
M"WB!"0`T?"$!;GP(`J:`J0`P@4D`.)-L_^PX@0`<DXS_\#^``8"3K/_T/Z`!
M@I/L__P[O0(HD`P`!#N<2XB2[/_<?'L;>),,_^!_@^-XDRS_Y)-,_^B3S/_X
MD0$`)#D```!A"($L@,D`/(#I`$"0H0`@@+T``'RH"2XXH```D4$`*($)`$2!
M20!(D,$`.)#A`#R`R0!,@.D`4)$!`$"100!$@0D`5(%)`%B!*0!<D,$`2)#A
M`$R1`0`LD4$`,)$A`#1,QC&"2__NY7Q_&WE!@@`0B3\``"^)``!`G@*L2__]
MP7Q^&WE!@@*T?\/S>$@`(UE48P@\.&,``4@`(+V(O@``?'D;>"^%``!!G@`P
M/T`!@'\_RW@[6DR8?^/[>']$TWA,QC&"2``B\8R^``$[_P`"+X4``$">_^2`
M80`X+X,``$&>`5P[X0`X2```$(1_``0O@P``09X!2#B!`!Q,QC&"2__N27Q^
M&WE!HO_DB3X``"^)``!!GO_82__TU2^#``!!GO_,?\/S>$@`('U\?AMY08(!
M#'_#\W@^X`&`2``BJ3KW3EA\?QMX?R/+>$@`(IE\?QH4.^,$!'_C^WA(`!_Y
M/.`!@#R``8!\>!MX?RC+>'_%\WA^YKMX..=,H#B$3*A,QC&"2``B,7\#PW@X
M@`'`2``AA2^#__]!G@%`.($`4'\#PWA(`"'!?'X;>4""`!2!(0!852D$)B^)
M0`!!G@'4@+L``#R``8`\8`&"?P;#>#B$3/`X8P'03,8Q@D@`()D[X```.2``
M`'_C^WAA*8$L?4D(+H$]``!]2DIY.2```$""!3"!80``@`L`!(+K_]R#"__@
M?`@#IH,K_^2#2__H@VO_[(.+__"#J__T@\O_^(/K__Q]85MX3H``(#L````Z
MX0`@.4```%<)$#IA2H$P?4H*%'TJ2A0]*?__@^E^\"^?``!!G@"XB3\``"^)
M``!!G@"L?^/[>%<:$#I+__-Q.]@``2^#``!_5](4?]CS>$">`#2'^@`$+Y\`
M`$&>`(")/P``+XD``$&>`'1_X_MX.]X``4O_\SE_V/-X+X,``$&>_]1_X_MX
M2``>W7Q^&WE!@O]T2__^8$@`'5V!(P``+XD`$4&>_KB#^P``2``=28#C```\
M@`&`/&`!@G_E^WA_!L-X.(1,M#AC`=`[X```3,8Q@D@`'V%+__[,.\```$O_
M_A1+__M1?^/[>$@`'GE\?QMX2__^L#M````[(0`<5U\0.CDA`"P[___\?^GZ
M%(1_``0O@P``09X!T'\DRW@[6@`!3,8Q@DO_Z^%\:1MY0:+_X(DI```OB0``
M09[_U$@`'B5\?AMY0(+]`$O__[2#00!L2``@<7^:&`!`GOXD@2$`6%4I!?XO
MB0'`0)[^%'_C^WA(`!VA.($`''Q_&W@\8`&`.&--1$S&,8)+_^M]+X,``$&>
M`7"#6P``2``=R7QD&WA_0]-X2__R]7QZ&WE!@@%4?T/3>$@`'^TK@P`#?'D;
M>$"=`#@\@`&`.&/__#B$34Q\>AH42``<W2^#``!`G@`<*YD`!$&>`DA_.LH4
MB3G_^R^)`"]!G@(X2__Y32^#``!`G@`<?T/3>#B```!,QC&"2``=87Q[&WE`
M@@#P/(`!@#Q@`8`XA$Q\.&-+]#]@`8!,QC&"2__N\3M[3B1(`!QE/(`!@'QG
M&WA_:-MX.(1-;'[FNWA_!<-X?^/[>#]``8!,QC&"2``?#3M:37Q(``!`2``;
M@8$C```OB0`10)X`1$@`'"$[W@`!?&<;>'_(\WA_:=MX?N:[>'\%PWA_1--X
M?^/[>$S&,8)(`![).(`!P'_C^WA(`!X=+X/__T&>_[1_`\-X2``>/7_D^WA_
M@^-X3,8Q@DO_[E%_X_MX2__Y54O__,`X8``-/\`!@$@`'"4[WDR0?'D;>#B@
M`%-+__ML@UL``$O__JPXX``".*#__SC`_^Y(`!M].($!+#B@``9_8]MX2``=
M78DA`2POB0``0)X`$(DA`2TOB0!#09X!,#C@```XH```.,```']CVWA(`!M!
M.\```$@`$RECWH``?'H;>$@``!`X@0$L?T/3>$@`$X%_Q?-X.($!+']CVWA(
M`!T!?&4;>4&!_^!_8]MX.R$!*$@`',U_1--X.2&!,#AA`.P_0`&`.\E_T#MA
M`.M(`!35.UI,F(R[``%_P_-X?T33>#O>``),QC&"2``=I7^9\$!`GO_D/0`!
M@#R``8`Y(```?N:[>#D(3B0XX0$`?P7#>#B$35Q_X_MXF2$!*$S&,8)(`!UM
M?P/#>$@`'/5_Y/MX?X/C>$S&,8)+_^T)?^/[>$O_^`U+__MX@WL`!"^;``!!
MOOW$?V/;>$@`'64K@P`#0+W]M#AC__P\@`&`?'L:%#B$351(`!I9+X,``$"^
M_9A_>MMX2__]D(DA`2XOB0!!0)[^S(DA`2\OB0!#0)[^P(DA`3`OB0!(0)[^
MM(DA`3$OB0!%0)[^J#C@``(XP/_&.*#__W]CVWA(`!GE.($!+']CVW@XH``I
M2``;Q3T``8`\@`&`..$!+'[FNW@Y"$XD.(1-7'\%PWA_X_MX3,8Q@D@`'(U+
M__W82``<Q90A_\!\"`*F/&`!@)/A`#P_X`&".___]).A`#20`0!$@3___)-A
M`"Q]*1(4DX$`,#^@`8*3P0`X.[T"*(%=``"100`<.4```#B!`!B!*0``.&-+
MV(E)`&2920!E3,8Q@DO_Y[4L`P``08(`$(DC```OB0`Q09X!;$O_\ZF#W__\
M/(`!@'_>$A0XA$V0@'X``#C```,XH``!2``:*7Q\&WE!@@`P@3P`##R@`8"`
M?@``.*5-E(")``!(`!HY@3P`#(")``"!)``(=2D`0$""`6R#W__\/(`!@'_>
M$A0XA$V<@'X``#C```,XH``!2``9U7Q[&WE!@@`P/&`!@#B!`!@X8TN43,8Q
M@DO_YPU\91MY08(!!($[``R`?@``@(D``$@`&=$_@`&".YP"=(/___P\@`&`
M?_\2%#B$3:"#WP``.*```7_#\WA(`!@9/*`!@'QD&W@XI4VX?\/S>$@`&96!
M/P``.4```#Q@`8"920!E.($`&#AC2XA,QC&"2__FF2^#``"0?`0(09X`:#B`
M`<!(`!I1+X,`$4&>`!`Y(P`!*XD``4&=`*"!(0`<@5T``'TI4GDY0```0((`
MK(`!`$2#80`L@X$`,'P(`Z:#H0`T@\$`.(/A`#PX(0!`3H``((DC``$OB0``
M0;[^E$O__HR`?`0$2__V92^#``"0?`0(0)[_C#Q@`8`X8TW`3,8Q@D@`%X$_
M@`&"@5L`##N<`G2`?@``@3P$!("*``"`J0``2``8P4O__OB`?@``2``7M4O_
M_I"!7`0$/2`!@("\!`A\9AMX@(H``#AI3>1,QC&"2``7,4@`&EV4(?_@?`@"
MII/!`!A\?AMXD^$`')`!`"1+__`5B2,``'Q_&W@OB0``09X`("N)`"\X8P`!
M0+X`"'Q_&WB)(P``+XD``$">_^A+__.E+X,``$&>`#0OG@``09X`+(D^```O
MB0``09X`(#R``8!_X_MX.(1,H#B@``1(`!=A+X,``$&>`!R``0`D@\$`&(/A
M`!Q\"`.F."$`($Z``""``0`D?\/S>(/A`!R#P0`8?`@#IC@A`"!+_^;HE"'^
M@#R``8(XA`(H..``$)-!`6@Y00`8DV$!;#D#`!B3@0%P?.D#II.A`723P0%X
MD^$!?($D``"1(0%<.2```'U)4WB$Z``$E.D`!$(`__@XH0$8?4A3>(3J``2!
M*``X@,@`)'^%4$"!"``,?2DR>'TI0GA]*3IX52D(/I$J`$!`GO_4@2$`'(`#
M``B`PP`,/2E:@H%C``0Y*7F9@8,``'P?,GB`HP`057WP/H%!`"!5GB@^?_]8
M.'P(ZG@\ZEJ"?2DJ%(%!`"1__S)X?2GR%'T(8#A5GO`^..=YF7TI^A1\YS(4
M/^I:@GT(`GA_JO)X?0@Z%'U*2#B`X0`H._]YF54\*#Y]2NIX52GP/G__`A1]
M".(4/V=:@GU*^A1_QTIX@^$`+%4<*#Y\YT`X.WMYF54(\#Y]2N(4?WOJ%'SG
M\GA]/4)X/Y]:@GSGVA157R@^?[U0.#N<>9E\Y_H4?YSR%(/A`#!_O4IX54KP
M/G^]XA14_"@^?[WB%'T>4GB#@0`T/_]:@CO_>9E_WC@X5.?P/GT_2A1_WD)X
M?5\Z>#^<6H)_WDH4.YQYF5>I*#Y__^@X?]Y*%'T<0A2!(0`X?_]2>%>]\#Y_
M_T(45\@H/G__0A0_B5J"@0$`/'SIZGA]*?`X.YQYF5?>\#Y_G%(4/0A:@GTJ
M.GA_J?)X5_LH/GU*XA0Y"'F9@X$`0'TI^#A]2MH45__P/GSH.A1]*>IX?\CZ
M>#]\6H)]*3H455PH/GTIXA0[>WF9?0A0.(.!`$151_`^?[OJ%'T(\GA_ZCIX
M?0CJ%#^<6H)5/2@^?4I(.'T(ZA0[G'F9@Z$`2%4I\#Y_G/(4?4KZ>'S^2G@_
M?5J"?4KB%%4=*#Y]2NH4?]Y`.(.A`$P[>WF950CP/G][^A1_WCIX?3]">#^=
M6H)_WMH455TH/G__4#A_WNH4.YQYF8.A`%!52O`^?YPZ%'__2GA]!U)X/WU:
M@G__XA17W2@^?__J%'SG\#B#H0!4.WMYF7][2A1\Z4)X5][P/C^=6H)]*=H4
M5_TH/GTIZA1]1_)X@Z$`6'SG^#@[G'F95__P/G^<0A1\YU)X?\CZ>#]=6H)]
M"$@X53TH/GSGXA0[6GF9?.?J%(.!`%Q_6E(4?0KR>%4I\#Y]2M(45.@H/G_]
M2GA]"D(4/WQ:@H%!`&!_O3@X.WMYF53G\#Y_>_(4/XI:@G^^^GB!00!D?3TZ
M>'_>VA1_O4`X51LH/CN<>9E5"/`^?][:%'^<^A0]2EJ"?[]*>'S]0GA7VR@^
M?__B%#E*>9E_O?`X@X$`:%?>\#Y__]H4?2I*%'^].GA]"O)X?[U*%#^<6H)7
MZ2@^?[U*%'U*^#B!(0!L.YQYF7^<.A1]1T)X5__P/CU);MI\Y^(45[PH/GSG
MXA2!(0!P?]SZ>#E*ZZ%_G.IX?4I"%%>]\#X]"6[:?4KB%%3\*#Y]2N(4@2$`
M='_\ZG@Y".NA?YPZ>'T(\A1]".(45/[P/E5<*#X\Z6[:?0CB%($A`'A_O/)X
M..?KH7^<4GA\Y_H4?.?B%%5?\#Y5'"@^/4ENVGSGXA2!(0!\?]SZ>#E*ZZ%_
MG$)X?4KJ%'U*XA15'?`^5/PH/CT);MI]2N(4@2$`@'_\ZG@Y".NA?YPZ>'T(
M\A1]".(45/[P/E5<*#X\Z6[:?0CB%($A`(1_O/)X..?KH7^<4GA\Y_H4?.?B
M%%5?\#Y5'"@^/4ENVGSGXA2!(0"(?]SZ>#E*ZZ%_G$)X?4KJ%'U*XA15'?`^
M5/PH/CT);MI]2N(4@2$`C'_\ZG@Y".NA?YPZ>'T(\A1]".(45/[P/E5<*#X\
MZ6[:?0CB%($A`)!_O/)X..?KH7^<4GA\Y_H4?.?B%%5?\#Y5'"@^/4ENVGSG
MXA2!(0"4?]SZ>#E*ZZ%_G$)X?4KJ%'U*XA15'?`^5/PH/CT);MI]2N(4@2$`
MF'_\ZG@Y".NA?YPZ>'T(\A1]".(45/[P/E5<*#X\Z6[:?0CB%($A`)Q_O/)X
M..?KH7^<4GA\Y_H4?.?B%%5?\#Y5'"@^/4ENVGSGXA2!(0"@?]SZ>#E*ZZ%_
MG$)X?4KJ%'U*XA15'?`^5/PH/CT);MI]2N(4@2$`I'_\ZG@Y".NA?YPZ>'T(
M\A1]".(45/[P/E5<*#X\Z6[:?0CB%($A`*A_O/)X..?KH7^<4GA\Y_H4?.?B
M%%5?\#Y5'"@^/4ENVGSGXA2!(0"L?]SZ>#E*ZZ%_G$)X?4KJ%'U*XA15'?`^
M5/PH/CT);MI]2N(4@2$`L'_\ZG@Y".NA?YPZ>'T(\A1]".(45/[P/E5<*#X\
MZ6[:?0CB%($A`+1_O/)X..?KH7^<4GA\Y_H4?.?B%%5?\#Y5'"@^/4ENVGSG
MXA2!(0"X?]SZ>#E*ZZ%]2NH4?YU">(.!`+Q5"/`^?4KJ%#TI;MI4_2@^?_M"
M>'U*ZA0Y*>NA5/WP/C^<CQQ_9SIX?2GR%#N<O-Q]'NMX?YSZ%'TI.A1]'^@X
M54<H/G_>4#A]*3H4?][[>(#A`,!52O`^53LH/G_>XA1_OU-X?][:%#SGCQR#
M80#$?[Q0.#CGO-Q__T@X?0="%%4I\#Y__^-X/YN/''U'2WA__T(4.YR\W%?(
M*#Y__T(4?YSJ%'SG\#A]74@X@0$`R%?>\#Y\Y^MX5_LH/GT]\WA\Y^(4/0B/
M''SGVA1]//`X@V$`S#D(O-Q_O?@X?4A2%'^]XWA7__`^/YN/''^]4A14ZB@^
M?[U2%'_(^WB!00#0.YR\W'T\2A1]"#@X?]SX.%3G\#Y]".-X/XJ/'#N<O-Q_
MZCMX5[LH/G^<\A1]"$H4?_XX.%>I\#Y]2N@X@Z$`U'T(VA1]2O-X?/Y+>#]]
MCQQ]2N(451TH/CM[O-Q]2NH4@Z$`V'_>0#A_>_H4?/](.%4(\#Y_W_MX/YV/
M''T^0WA572@^?__:%#N<O-Q__^H4?]Y0.(.A`-Q_G#H4?2=`.%5*\#Y_QSMX
M/WV/''SGXA17_2@^?.?J%'T>4WB#H0#@.WN\W'_>^#A_>TH4?0E0.%?_\#Y_
MR4MX/YV/''U>^WA4_2@^?2G:%#N<O-Q]*>H4?]XX.(.A`.1_G$(4?4CX.%3G
M\#Y_R$-X/WV/''T(XA15/2@^?0CJ%'_^.WB#H0#H.WN\W'_>2#A_>U(4?^HX
M.%4I\#Y_RE-X/YV/''S^2WA5'2@^?4K:%#N<O-Q]2NH4?YSZ%(.A`.Q\_T@X
M?]Y`.%4(\#Y_WOMX/WV/''_>XA1572@^?][J%'T_0WB#H0#P.WN\W'][.A1_
M_U`X?2=`.%5*\#Y__SMX/YV/''T'4WA7W2@^?__:%#N<O-Q__^H4?.?P.(.A
M`/1_G$H4?0E0.%?>\#Y\Z4MX/WV/''TIXA17_2@^?2GJ%'U'\WB#H0#X.WN\
MW'][0A1\Y_@X?4CP.%?_\#Y\YT-X/YV/''_(^WA5/2@^?.?:%#N<O-Q\Y^H4
M?YQ2%'T(2#A_RO@X@Z$`_%4I\#Y]"%-X5/LH/G_J2WA]".(4/[V/''T(VA1_
M_$@X@V$!`#N]O-Q]2C@X?]WR%'U*XWA4Y_`^/YN/''U*\A15'B@^?4KR%'T]
M.WB#P0$$.YR\W'_\^A1_O4`X?3PX.%4(\#Y_O>-X/YZ/''S^0WA_O?H455LH
M/E5?\#X[G+S<?]Y0.(%!`0A]/$H4?/Q`.'^]VA1_WN-X/XJ/''_>2A1]"OMX
M5ZDH/CN<O-Q_WDH4?4KH.'^<.A2!(0$,?0?X.%>]\#Y]1SMX/4G*8WSGXA17
MW"@^?.?B%($A`1!__.IX.4K!UG^<\GA]2D(45][P/CT)RF-]2N(45/PH/GU*
MXA2!(0$4?[SR>#D(P=9_G#IX?0CZ%'T(XA14__`^55PH/CSIRF-]".(4@2$!
M&'_<^G@XY\'6?YQ2>'SGZA1\Y^(455WP/E4<*#X]2<IC?.?B%($A`1Q__.IX
M.4K!UG^<0GA]2O(4?4KB%%4>\#Y4_"@^/0G*8WU*XA2!(0$@?[SR>#D(P=9_
MG#IX?0CZ%'T(XA14__`^55PH/CSIRF-]".(4@2$!)'_<^G@XY\'6?YQ2>'SG
MZA1\Y^(455WP/E4<*#X]2<IC?.?B%($A`2A__.IX.4K!UG^<0GA]2O(4?4KB
M%%4>\#Y4_"@^/0G*8WU*XA2!(0$L?[SR>#D(P=9_G#IX?0CZ%'T(XA14__`^
M55PH/CSIRF-]".(4@2$!,'_<^G@XY\'6?YQ2>'SGZA1\Y^(455WP/E4<*#X]
M2<IC?.?B%($A`31__.IX.4K!UG^<0GA]2O(4?4KB%%4>\#Y4_"@^/0G*8WU*
MXA2!(0$X?[SR>#D(P=9_G#IX?0CZ%'T(XA14__`^55PH/CSIRF-]".(4@2$!
M/'_<^G@XY\'6?YQ2>'SGZA1\Y^(455WP/E4<*#X]2<IC?.?B%($A`4!__.IX
M.4K!UG^<0GA]2O(4?4KB%%4>\#Y4_"@^/0G*8WU*XA2!(0%$?[SR>#D(P=9_
MG#IX?0CZ%'T(XA14__`^55PH/CSIRF-]".(4@2$!2'_<^G@XY\'6?YQ2>'SG
MZA1\Y^(455WP/E4<*#X]2<IC@2$!3'SGXA0Y2L'6?_SJ>'^<0GA]2O(451[P
M/CT)RF.!(0%0?4KB%%3\*#XY",'6/2G*8WU*XA0Y*<'6?[SR>'^<.GA]"/H4
M?2GJ%(.A`514__`^?0CB%%5'*#Y_W/IX?0@Z%#^]RF.`X0%8?YQ2>#N]P=95
M2O`^?2GB%'_=\A15'"@^?_U2>#SGRF-]*>(4?[U">#CGP=95"/`^?][J%%4\
M*#Y]74)X?.=B%'^]2GA_GN(4?.?Z%'SGZA17GB@^?.?R%%4I\#Z0XP``?09"
M%'U%4A1]:^(4?2D"%(#A`5R`Q```?.<R>3C```"10P`0D0,`#)%C``21(P`(
M0((`)(-!`6B#80%L@X$!<(.A`72#P0%X@^$!?#@A`8!.@``@?`@"II`!`81(
M``LUE"'_\'P(`J8X8`!@D`$`%$@`"($\@&=%/*#OS3S`F+H\X!`R/0##TCE`
M``!@A",!8*6KB6#&W/Y@YU1V80CA\)"#``"0HP`$D,,`")#C``R1`P`0D4,`
M%)%#`!B10P!<@`$`%#@A`!!\"`.F3H``()0A_]!\"`*F5*D8.%2H'WZ300`8
M?)HC>)-A`!R3@0`@?+PK>)/A`"Q\?QMXD`$`-#M_`!R3P0`H@4,`%(!C`%Q]
M*5(4@/\`&'U*2!`O@P``?4I1$)$_`!1\ZCA0?0@Z%)$?`!A!G@!<(2,`0'R^
M*WA_A4@`09T`X'Q[&A1_Q?-X?T33>$@`"@V!/P!<?3Y*%"^)`$"1/P!<09X`
MY(`!`#2#00`8@V$`''P(`Z:#@0`@@\$`*(/A`"PX(0`P3H``().A`"0OG``_
M?YWC>']>TWA`G0!(?\3S>#B@`$!_8]MX.[W_P$@`":U_X_MX2__P-2^=`#\[
MW@!`09W_W#N<_\!7B=&^'4G_P#DI``%5*3`R?XKB%']:2A1_1--X?V/;>'^%
MXWA(``EMDY\`7(`!`#2#H0`D@T$`&'P(`Z:#80`<@X$`((/!`"B#X0`L."$`
M,$Z``"!]/DMX?'L:%'_%\WA_1--X2``)+8$_`%Q]/DH4+XD`0)$_`%Q`GO\D
M?^/[>).A`"1_GN!0?UKR%$O_[Y5+__\TE"'_T'P(`J8Y0/^`DV$`'#MD`!R3
MP0`H?'X;>)/A`"Q\GR-XD`$`-).!`""3H0`D@Z0`%(.$`!A7J>Z^.*D``7U;
M2:XOA0`X?'LJ%$"=`40@I0!`.(```$@`!?5_X_MX2__O+7]CVW@XH``X.(``
M`$@`!=U7J<(^5X5&/E>&A#Y7A\(^5ZA&/E>JA#Z;GP!7?^/[>)N_`%N9/P!:
MF+\`5)C?`%68_P!6F1\`6)E?`%E+_^[=B3\``'_C^WB9/@``H3\``)D^``&!
M/P``52G"/ID^``*!/P``F3X``XD_``29/@`$H3\`!)D^``6!/P`$52G"/ID^
M``:!/P`$F3X`!XD_``B9/@`(H3\`")D^``F!/P`(52G"/ID^``J!/P`(F3X`
M"XD_``R9/@`,H3\`#)D^``V!/P`,52G"/ID^``Z!/P`,F3X`#XD_`!"9/@`0
MH3\`$)D^`!&!/P`052G"/ID^`!*!/P`0F3X`$X`!`#2#80`<@X$`('P(`Z:#
MH0`D@\$`*(/A`"PX(0`P2``&\""E`#@X@```2``$M4O__MB4(?_@?`@"ID*?
M``63P0`8?\@"IC_>``*0`0`D.]X],(%>@`2)*@`D+XD``$">`&R3@0`0.2``
M`9/A`!R#GH`8@_Z`%)DJ`"1_G^!`0)P`,).A`!0[___\@3\`!#N_``0[_P`(
M?2D#IDZ`!"%_G^!`?[_K>$&<_^2#H0`4@3Z`'"^)``!!G@`H@'Z`#$@`!2&#
M@0`0@^$`'(`!`"2#P0`8."$`('P(`Z9.@``@@`$`)(.!`!"#X0`<?`@#IH/!
M`!@X(0`@3H``()0A_^!\"`*F0I\`!9/!`!A_R`*F/]X``I`!`"0[WCQH@)Z`
M!(DD```OB0``0)X`6($^@`@Y0``!DZ$`%"^)``"3X0`<F40``$&>`!"`?H`,
M.(0`!$@`!0&#_H``@[Z`$'^?Z$!`G0`8A3___'TI`Z9.@`0A?Y_H0$&=__"#
MH0`4@^$`'(`!`"2#P0`8."$`('P(`Z9.@``@E"'_P'P(`J:3P0`X/\`!@I!A
M`!P[W@(HD($`&#AA`!R0H0`4.($`&#BA`!2!/@``D2$`+#D@``"0`0!$D^$`
M/$@`!$T\H`&`/&`!@#BE2*`X8TA0?*0K>$@``N4](`&"B^D!&"^?``!!G@%4
M/2`!@I.A`#0Y*?_T@Z$`'($I__Q]*1(4/4`__X$)```X?0`$84K__SN]``-_
M@U!`B2@#UF$I``.9*`/609T!H%1C$#H_X`&"2``$.8#A`!R!00`8/2`!@B^'
M``&`R0$$@*H``#T``8`](`&`.0A.*#DI3BP[_P)T?&L;>)"C``"1`P`$D,,`
M")$C``R0?P0$0)T!1%3I$#HY`P`,.2G_^%4I\+XY*0`!?2D#IH4J``25*``$
M0@#_^#CG``-4Z1`Z/(`!@(!_!`Q_I>MX.4```#B$&#Q]9EMX..```'U+22Y(
M``)Q?'T;>4&"`+2`?P0,2``#(3Q@`8`X@0`H.&-+Z$S&,8)+_]`1+X,``$&>
M`'R`?P0,2``$C4@``/F!(0`L@5X``'TI4GDY0```?Z/K>$""`,2``0!$@Z$`
M-(/!`#A\"`.F@^$`/#@A`$!.@``@2``"83U``8(O@P``D&H&@).A`#1!G@"4
M2``#.3T@`8(Y*?_T@4G__'U*$A2!2@``F^H&=DO__HB`?P0(+X,``$&>`!Q+
M_^G52___>(!_!`Q(``+!?'T;>$O__T0\8`&`.($`*#AC2XA,QC&"2__/62^#
M``"0?P0(09[_2$O_Z9U+__]`.2``$$O__N@\@`&"/&`!@#B$_I@X8TUH3,8Q
M@D@``*%(``/-.&```4@``C4]8`&"@6L``'UI`Z9.@`0@/6`!@H%K``1]:0.F
M3H`$(#U@`8*!:P`(?6D#IDZ`!"`]8`&"@6L`#'UI`Z9.@`0@/6`!@H%K`!!]
M:0.F3H`$(#U@`8*!:P`4?6D#IDZ`!"`]8`&"@6L`&'UI`Z9.@`0@/6`!@H%K
M`!Q]:0.F3H`$(#U@`8*!:P`@?6D#IDZ`!"`]8`&"@6L`)'UI`Z9.@`0@/6`!
M@H%K`"A]:0.F3H`$(#U@`8*!:P`L?6D#IDZ`!"`]8`&"@6L`,'UI`Z9.@`0@
M/6`!@H%K`#1]:0.F3H`$(#U@`8*!:P`X?6D#IDZ`!"`]8`&"@6L`/'UI`Z9.
M@`0@/6`!@H%K`$!]:0.F3H`$(#U@`8*!:P!$?6D#IDZ`!"`]8`&"@6L`2'UI
M`Z9.@`0@/6`!@H%K`$Q]:0.F3H`$(#U@`8*!:P!0?6D#IDZ`!"`]8`&"@6L`
M5'UI`Z9.@`0@/6`!@H%K`%A]:0.F3H`$(#U@`8*!:P!<?6D#IDZ`!"`]8`&"
M@6L`8'UI`Z9.@`0@/6`!@H%K`&1]:0.F3H`$(#U@`8*!:P!H?6D#IDZ`!"`]
M8`&"@6L`;'UI`Z9.@`0@/6`!@H%K`'!]:0.F3H`$(#U@`8*!:P!T?6D#IDZ`
M!"`]8`&"@6L`>'UI`Z9.@`0@/6`!@H%K`'Q]:0.F3H`$(#U@`8*!:P"`?6D#
MIDZ`!"`]8`&"@6L`A'UI`Z9.@`0@/6`!@H%K`(A]:0.F3H`$(#U@`8*!:P",
M?6D#IDZ`!"`]8`&"@6L`D'UI`Z9.@`0@/6`!@H%K`)1]:0.F3H`$(#U@`8*!
M:P"8?6D#IDZ`!"`]8`&"@6L`G'UI`Z9.@`0@/6`!@H%K`*!]:0.F3H`$(#U@
M`8*!:P"D?6D#IDZ`!"`]8`&"@6L`J'UI`Z9.@`0@/6`!@H%K`*Q]:0.F3H`$
M(#U@`8*!:P"P?6D#IDZ`!"`]8`&"@6L`M'UI`Z9.@`0@/6`!@H%K`+A]:0.F
M3H`$(#U@`8*!:P"\?6D#IDZ`!"`]8`&"@6L`P'UI`Z9.@`0@/6`!@H%K`,1]
M:0.F3H`$(#U@`8*!:P#(?6D#IDZ`!"`]8`&"@6L`S'UI`Z9.@`0@/6`!@H%K
M`-!]:0.F3H`$(#U@`8*!:P#4?6D#IDZ`!"`]8`&"@6L`V'UI`Z9.@`0@/6`!
M@H%K`-Q]:0.F3H`$(#U@`8*!:P#@?6D#IDZ`!"`]8`&"@6L`Y'UI`Z9.@`0@
M/6`!@H%K`.A]:0.F3H`$(#U@`8*!:P#L?6D#IDZ`!"`]8`&"@6L`\'UI`Z9.
M@`0@/6`!@H%K`/1]:0.F3H`$(#U@`8*!:P#X?6D#IDZ`!"!(``$`2```_$@`
M`/A(``#T2```\$@``.Q(``#H2```Y$@``.!(``#<2```V$@``-1(``#02```
MS$@``,A(``#$2```P$@``+Q(``"X2```M$@``+!(``"L2```J$@``*1(``"@
M2```G$@``)A(``"42```D$@``(Q(``"(2```A$@``(!(``!\2```>$@``'1(
M``!P2```;$@``&A(``!D2```8$@``%Q(``!82```5$@``%!(``!,2```2$@`
M`$1(``!`2```/$@``#A(```T2```,$@``"Q(```H2```)&````!@````8```
M`&````!@````8````&````!@````/8`!@CUK_H"`#/_X.6NVD'P)`Z9\"UH4
M@8S__'U@6A1.@`0@8````&````!@````8````&````!@````8````'P(`J:0
M`0`$E"'_\$O_]ODX(0`0@`$`!'P(`Z9.@``@<'-?<W1R:6YG<R!M:7-S:6YG
M"@!P97)L>'-I+F,```!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@
M(``````!@$Y0`8!+1``````!@$Q``8!,1`&`3D0!@$N,`8!.3``````!@$XP
M`8!..``````N````+BX``"5S+R5S````1'EN84QO861E<CHZ8F]O=%]$>6YA
M3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`````%!!4E]414U0`````%!!
M4E]04D]'3D%-10`````Z````)7,E<R5S``!015),-4Q)0@````!015),3$E"
M`%!%4DPU3U!4`````%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%7
M3D5$`%!!4E]#3$5!3@```%!!4E]$14)51P```%!!4E]#04-(10```%!!4E]'
M3$]"04Q?1$5"54<`````4$%27T=,3T)!3%]435!$25(```!005)?5$U01$E2
M``!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@````!005)?0TQ%
M04X]```Q````3$1?3$E"4D%265]0051(`%-94U1%30``)3`R>`````!P87(M
M`````"5S)7,E<R5S`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I
M<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``"5S.B!P<FEV871E('-U
M8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD
M(')E=')Y('EO=7(@;W!E<F%T:6]N*0H``%!!5$@`````<&%R;``````N<&%R
M`````"5S)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S````)7,E<W1E;7`M
M)74M)74E<P`````8````<&5R;``````P````4$%2.CI086-K97(Z.E9%4E-)
M3TX`````,2XP-3(```!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R
M>0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O
M<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`````"UE```M+0``55-%4@````!5
M4T523D%-10````!414U01$E2`%1-4``O=F%R+W1M<"\```!E=F%L("=E>&5C
M("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@
M<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY
M("@D4$%27TU!1TE#+"`D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L
M("5-;V1U;&5#86-H92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*
M<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR
M97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M
M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S
M(&EN("(D<&%R7W1E;7`B72D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@
M>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I
M<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I
M;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^
M("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D
M=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY
M("1F:6QE;F%M92`]("1T;7`M/F9I;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN
M+B(["G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A
M<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*
M9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M
M92<*+BXN"F-L;W-E("1T;7`["F-H;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@
M)&-M9"`]("(D9FEL96YA;64@/B]D978O;G5L;"`R/B8Q("8B.PIS>7-T96TH
M)&-M9"D["F]U=',H<7%;4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@
M<&5R9F]R;2!C;&5A;G5P.B`D9FEL96YA;65=*3L*?0I]('T*0D5'24X@>PI)
M;G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ
M4$%2.CI"3T]4.PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PIE=F%L('L*
M7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=]
M.PIM>2`E0V]N9FEG(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7
M:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_
M.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*
M7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY("@D<W1A<G1?
M<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L("1324=[7U]705).7U]](#T@<W5B
M('M].PIO<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE(&]R(&QA<W0["FUY
M("1B=68["FUY("1S:7IE(#T@+7,@)'!R;V=N86UE.PIM>2`D8VAU;FM?<VEZ
M92`](#8T("H@,3`R-#L*;7D@)&UA9VEC7W!O<SL*:68@*"1S:7IE(#P]("1C
M:'5N:U]S:7IE*2!["B1M86=I8U]P;W,@/2`P.PI](&5L<VEF("@H;7D@)&T@
M/2`D<VEZ92`E("1C:'5N:U]S:7IE*2`^(#`I('L*)&UA9VEC7W!O<R`]("1S
M:7IE("T@)&T["GT@96QS92!["B1M86=I8U]P;W,@/2`D<VEZ92`M("1C:'5N
M:U]S:7IE.PI]"G=H:6QE("@D;6%G:6-?<&]S(#X](#`I('L*<V5E:R!?1D@L
M("1M86=I8U]P;W,L(#`["G)E860@7T9(+"`D8G5F+"`D8VAU;FM?<VEZ92`K
M(&QE;F=T:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F
M+"`D4$%27TU!1TE#*2D@/CT@,"D@>PHD;6%G:6-?<&]S("L]("1I.PIL87-T
M.PI]"B1M86=I8U]P;W,@+3T@)&-H=6YK7W-I>F4["GT*;&%S="!I9B`D;6%G
M:6-?<&]S(#P@,#L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T+"`P.PIR96%D
M(%]&2"P@)&)U9BP@-#L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T("T@=6YP
M86-K*").(BP@)&)U9BDL(#`["B1D871A7W!O<R`]('1E;&P@7T9(.PIM>2`E
M<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@
M("`@("`@("`@("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H
M)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(
M+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U
M9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE(BXN+ETI.PIM
M>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@
M/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^
M(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR
M96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D
M*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM
M>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U
M*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N
M86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L
M;&YA;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N
M9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?
M<V%V95]A<R@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")3
M2$Q)0CH@)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD
M9G5L;&YA;65](#T*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]
M/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["GT*
M<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H
M)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O
M<B`A)&UO9'5L93L*;7D@)&EN9F\@/2!D96QE=&4@)')E<75I<F5?;&ES='LD
M;6]D=6QE?2!O<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D
M:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE
M9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T
M;7!F:6QE(&]R(&1I92`B0V%N)W0@8W)E871E('1E;7`@9FEL93H@)"$B.PHD
M9F@M/F)I;FUO9&4H*3L*)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M
M/G-E96LH,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M
M92`](%]S879E7V%S*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI
M.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&5N86UE(&]R(&1I92!Q<5M#
M86XG="!R96%D("(D9FEL96YA;64B.B`D(5T["G)E='5R;B`D9F@["GT*9&EE
M(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N)W0@9FEN9"!M;V1U;&4@)&UO
M9'5L92$B.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!0
M05(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R
M=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR
M97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@
M:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N
M86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M
M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@
M>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O
M;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M
M97T["GT*;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R
M=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R
M="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D
M;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]21553
M17T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L
M96TI"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D
M<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@
M<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*
M:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A
M<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q
M("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%
M?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V
M:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=
M(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D
M,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q
M(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I
M('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I
M('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]
M("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL
M)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@
M*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q
M6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E
M<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF
M("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%2
M7U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!
M4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z
M.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#
M+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ
M1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI3
M2$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E
M9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D
M:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H
M)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH
M("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI
M=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II
M<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@
M86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*
M)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS
M.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*:68@*&1E
M9FEN960@)'!A<BD@>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D
M:64@<7%;0V%N)W0@<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U
M9CL*<F5A9"`D<&@L("1B=68L(#0["F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@
M<&%R(&9I;&5=('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*8VQO<V4@
M)'!H.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^
M;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?
M5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I
M92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM
M;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE
M9"`D9&%T85]P;W,I('L*<F5A9"!?1D@L("1L;V%D97(L("1D871A7W!O<SL*
M?2!E;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]
M"FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z
M(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]
M"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]
M("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L
M(#U^("]>6R<B72\["FUY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K
M97DI("X@(E]?(CL*;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD
M=F%L(CL*)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T
M("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]
M"B1F:"T^<')I;G0H)&QO861E<BD["FEF("@D8G5N9&QE*2!["G)E<75I<F4@
M4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII
M;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@
M>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH
M)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D
M0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG
M+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK
M*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@
M)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[
M("`@("`@("`@(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N
M.PIF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F
M:6QE+"`D;F%M92D["FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL
M("1F8RD["GT*96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H
M)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I
M(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R
M+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD
M,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF
M("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B
M+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M
M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F
M:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P
M<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D
M9FEL92T^>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H
M)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL
M;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&4@
M;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`]
M(#PD9F@^.PIC;&]S92`D9F@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P
M;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!
M4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*
M4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E
M;G0L("1F:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH
M)TXG+"!L96YG=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!
M<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*
M<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D["F]U=',H
M<7%;5W)I='1E;B!A<R`B)&YA;64B72D["GT*?0HD>FEP+3YW<FET951O1FEL
M94AA;F1L92@D9F@I(&EF("1Z:7`["B1C86-H95]N86UE(#T@<W5B<W1R("1C
M86-H95]N86UE+"`P+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT
M:6UE(#T@*'-T870H)&]U="DI6SE=*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(
M02T^;F5W*#$I.PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)&]U=#L*)&-T>"T^
M861D9FEL92@D9F@I.PIC;&]S92`D9F@["B1C86-H95]N86UE(#T@)&-T>"T^
M:&5X9&EG97-T.PI]"B1C86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG
M=&@@)&-A8VAE7VYA;64I.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M
M/G!R:6YT*"1C86-H95]N86UE*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H
M+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D["B1F:"T^<')I;G0H)%!!4E]-
M04=)0RD["B1F:"T^8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*
M>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA
M;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D
M97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ
M6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)
M3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I
M92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#
M:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W
M.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@
M/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E
M861I;F<@>FEP(&%R8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z
M.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE
M+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U
M:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-
M4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FEF("AD969I;F5D("1%3E9[4$%2
M7U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E
M86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M
M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R
M+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*
M+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#
M;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D
M97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C
M+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@
M*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S
M9613:7IE*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S
M:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E
M;'-E('L*;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D
M9&5S=%]N86UE(ETI.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E
M<W1?;F%M92D["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B
M:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA
M;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M
M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=
M(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N
M<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S
M:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@
M0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P
M871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L
M("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM
M:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@
M=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI
M8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I
M<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E
M<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N
M;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97([
M"G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&
M:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*
M<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E
M($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER
M92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V
M>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E
M<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@
M>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I
M;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*
M979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A
M;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T[
M"F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"![
M"FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0
M?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E
M86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@
M5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP
M("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A
M=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A
M;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII
M9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@
M/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I
M('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D
M14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U
M<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N
M9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD
M:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M
M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N(&UY("1F
M:"P@(CPZ<F%W(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D
M<')O9VYA;64B.B`D(5T["G-E96L@)&9H+"`M,3@L(#(["FUY("1B=68["G)E
M860@)&9H+"`D8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E
M:R`D9F@L("TU."P@,CL*<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O
M7#`O+V<["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TD8G5F
M(CL*?0IE;'-E('L*;7D@)&1I9V5S="`](&5V86P*>PIR97%U:7)E($1I9V5S
M=#HZ4TA!.PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;B!M
M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A
M9"`B)'!R;V=N86UE(CH@)"%=.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E
M*"1F:"D["B1C='@M/FAE>&1I9V5S=#L*?2!\?"`D;71I;64["B1S=&UP9&ER
M("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TD9&EG97-T(CL*?0IC;&]S92@D
M9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N
M/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@
M/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["FQA<W0["GT*)'!A
M<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%
M35!](#U^("\H+BLI+SL*?0IS=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C
M;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E
M;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA
M;64@/2`B)&9U;&QN86UE+B0D(CL*;W!E;B!M>2`D9F@L("<^.G)A=R<L("1T
M96UP;F%M92!O<B!D:64@<7%;0V%N)W0@=W)I=&4@(B1T96UP;F%M92(Z("0A
M73L*<')I;G0@)&9H("1C;VYT96YT<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D
M92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA
M;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N
M("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D
M("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^
M("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P
M.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.
M5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G
M;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I
M.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M
M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@
M)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@
M(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D0V]N
M9FEG>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET
M("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@
M:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%2
M7U1%35!].PHD9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL**"@D
M<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF
M:6=[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD
M<')O9VYA;64D0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1#
M;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#
M;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M
M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF
M("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P
M<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D
M<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*
M.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I
M(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN
M7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\[
M"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I
M;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I
M('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R
M.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!0
M4D]'3D%-12`I("D@>PID96QE=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H
M<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N
M)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG
M4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!
M4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]
M*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@
M)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H
M)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#
M3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]
M"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2![
M"G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*
M?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L
M(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA
M<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV
M96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*
M<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI0
M05(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O
M<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@
M9&ER96-T;W)Y7&Y="G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M
M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI
M7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`[
M"GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E4
M7UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ
M.PI?7T5.1%]?"@```1L#.P```/`````=__^(4````0C__XB\```!./__B5@`
M``%X__^*N````C3__XO@```"G/__C*@```+,__^.8````V3__X[8```#C/__
MD5P```/D__^2!```!!#__Y(\```$*/__DDP```1`__^5````!-3__Y4X```$
M[/__EL0```4\__^8^```!7#__YFL```%J/__F>0```7,__^:_```!@C__Z*D
M```&3/__I0P```:$__^EQ```!O3__[0T```'+/__M*0```=,__^V.```!ZC_
M_[?8```!Z/__N*````&X__^Y.```!KC__[ND```!I````!```````7I2``1\
M00$;#`$`````+````!C__X=`````;`!!#B!!"4$`0IX"19T#GP%#$4%_3`9!
M0M_>W0X`````````/````$C__X=\````G`!!#B!!"4$`0IX"19P$GP%$$4%_
M0YT#3]U$!D%"W][<#@!!#B"<!)T#G@*?`1%!?P```"@```"(__^'V````6``
M00X@00E!`$*<!$*>`D6;!1%!?T&=`T&?`0``````$````+3__[GX```%,```
M```````L````R/__MN````"8`$$.($$)00!"G@)'$4%_1)T#0I\!3]U!WT/>
M#@!!!D$```!(````^/__M>@```#(`$$.($$)00!"G@)'$4%_0IP$0I\!1IT#
M2MU&W$'?0]X.`$$&04$.()P$G@*?`1%!?T+<0=]!!D%"W@X`````9````43_
M_XA\```!*`!"#C!!GP%#FP5$G@)*"4$`09H&01%!?T*<!$*=`T_:0=M!!D%!
MW$'=0=Y#WPX`00XPFP6>`I\!2)H&G`2=`Q%!?T;:W-T&04$*VT'>00M"V]Y"
MFP5"VP`````L```!K/__B3P```#(`$$.,$()00"=`T@107^>`I\!8PH&04+?
MWMT.`$$+``````"4```!W/__B=0```&X`$$.T`%!G0-"GP%1"M_=#@!!"T$)
M00!!G`1!$4%_1)D'0IH&0IL%0IX"5)@(6]A!V=K;WD+<009!09D'F@:;!9P$
MG@(107]&V4':009!0=M!W$'>09@(F0>:!IL%G`2>`A%!?T+8V=K;W-X&04$)
M00!!F`A!$4%_09D'09H&09L%09P$09X"`````"0```)T__^*]````'@`00X@
M1`E!`)\!0Q%!?U0&04'?#@````````!4```"G/__BT0```*$`$$.4$0107^;
M!9P$0YT#G@)+GP&9!YH&`D0*!D%&W][=W-O:V0X`00M)F`A!EPEC"M=!V$$+
M2-?80I<)F`A$UT'80Y<)09@(````*````O3__XUP````J`!!#L`!1`E!`)X"
MGP%"$4%_6`H&04'?W@X`00L````4```#(/__C>P````X`$(.$$L.```````4
M```#./__C@P````0`$$.$$(.``````"0```#4/__C@0```*T`$$.\`E$"4$`
MG0-$G@*?`4H107^;!05&#%4*"48,0@9!0@9&0]_>W=L.`$$+09P$0Y4+09H&
M298*0I<)0I@(0ID'>0K50=9!UT'80=E!VD'<00M6U4'60==!V$'90=I!W$&5
M"YH&G`1!U4':0=Q"E0M!E@I!EPE!F`A!F0=!F@9!G`0`````%````^3__Y`D
M````.`!!#A!,#@``````3````_S__Y!$```!C`!!#B!!GP%#G@)$"4$`01%!
M?U;>0@9!0=\.`$$.()X"GP%!WD3?#@!!#B">`I\!$4%_:@K>0@9!0=\.`$$+
M```````P```$3/__D8````(T`$$.8$H107^;!9P$G0-"G@)"GP$"80H&043?
MWMW<VPX`00L`````-```!(#__Y.`````M`!!#C!!G@)#GP%0"M_>#@!!"T()
M00!#$4%_3@9!0@E!`$$107\````````@```$N/__D_P````X`$$.$$(107]'
M"@X`009!00L````````X```$W/__E!````$8`$$.0$()00">`D:<!)T#GP%(
M$4%_39L%5=M-"@9!0]_>W=P.`$$+09L%``````!````%&/__E.P```>H`$<.
MX(("1@E!`)L%G`1"G0-,GP$107^7"9@(F0>:!IX"`H@*!D%(W][=W-O:V=C7
M#@!!"P```#0```5<__^<4````F@`00Y`0PE!`)\!2)T#$4%_FP6<!$*>`@)E
M"@9!1-_>W=S;#@!!"P``````,```!93__YZ`````N`!!#B!""4$`G@)#GP$1
M07]?"@9!0=_>#@!!"T4&04'?W@X``````#@```7(__^R>````FP`00Y`0@E!
M`)X"31%!?Y\!39T#`DW=0@9!0M_>#@!!#D">`I\!$4%_19T#`````#0```8$
M__^>R```#G``00Z``U":!IL%G`2=`YX"GP$#`X<*W][=W-O:#@!!"T$)00!!
M$4%_````'```!CS__ZT`````<`!!#A!#$4%_5@X`009!``````!8```&7/__
MK5````&4`$$.,$0)00":!D.;!9P$0I\!3Q%!?YX"4@H&043?WMS;V@X`00M!
MG0-<W4(&047?WMS;V@X`00XPF@:;!9P$G@*?`1%!?TR=`P```````#0```:X
M__^NB````:``00XP0PE!`)L%0IX"0I\!1!%!?YP$G0,"4PH&043?WMW<VPX`
M00L`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````#_____
M`````/____\``````````````````````````````````````8(!``&!_H0!
M@?Z$`8`.X`&`#N`!@?Z$`8'^A`&`2M`!@@$(`8(!$`&"`0`!@@)(`8'_$`&!
M_H0!@!(L`8'^A`&`2K`!@?Z(`8("3``````!@(N4`8'^B`&!_I`!@?Z0````
M``````$````!`````0```D,````!```"30````$```*)`````0```J\````/
M```$.0````P!@!'L````#0&`2K`````$`8`!>`````4!@`H@````!@&`!!``
M```*```$@0````L````0````%0`````````#`8(```````(```+T````%```
M``<````7`8`.^'`````!@?_T````!P&`#J0````(```#2`````D````,````
M````````````````````````````````````````````````````````````
M``````&!_Q````````````&`27`!@$ET`8!)>`&`27P!@$F``8!)A`&`28@!
M@$F,`8!)D`&`290!@$F8`8!)G`&`2:`!@$FD`8!)J`&`2:P!@$FP`8!)M`&`
M2;@!@$F\`8!)P`&`2<0!@$G(`8!)S`&`2=`!@$G4`8!)V`&`2=P!@$G@`8!)
MY`&`2>@!@$GL`8!)\`&`2?0!@$GX`8!)_`&`2@`!@$H$`8!*"`&`2@P!@$H0
M`8!*%`&`2A@!@$H<`8!*(`&`2B0!@$HH`8!*+`&`2C`!@$HT`8!*.`&`2CP!
M@$I``8!*1`&`2D@!@$I,`8!*4`&`2E0!@$I8`8!*7`&`2F`!@$ID`8!*:/__
M__\!@@)(`8!.7$=#0SH@*$YE=$)31"!N8C,@,C`Q.3`S,3DI(#<N-"XP`$=#
M0SH@*&YB,R`R,#$Y,#,Q.2D@-RXT+C``)$YE=$)31#H@8W)T,"Y3+'8@,2XW
M(#(P,3@O,3$O,C8@,3<Z,S<Z-#4@:F]E<F<@17AP("0`)$YE=$)31#H@8W)T
M,"UC;VUM;VXN8RQV(#$N,C,@,C`Q."\Q,B\R."`R,#HQ,CHS-2!C:')I<W1O
M<R!%>'`@)``D3F5T0E-$.B!C<G1I+E,L=B`Q+C0@,C`Q-"\P,R\P-B`Q.3HP
M-3HU.2!M871T($5X<"`D`"1.971"4T0Z(&-R=&)E9VEN+F,L=B`Q+C$W(#(P
M,3@O,3(O,C@@,3@Z,3<Z,3$@8VAR:7-T;W,@17AP("0`)$YE=$)31#H@8W)T
M96YD+E,L=B`Q+C,@,C`Q-"\P,B\R-R`Q-CHT-SHT."!M871T($5X<"`D`"1.
M971"4T0Z(&-R=&XN4RQV(#$N,B`R,#$T+S`R+S(W(#$V.C0W.C0X(&UA='0@
M17AP("0``"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+FYE=&)S9"YI9&5N=``N
M;F]T92YN971B<V0N<&%X`"YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N<F5L82YD
M>6X`+G)E;&$N<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R
M86UE7VAD<@`N96A?9G)A;64`+F-T;W)S`"YD=&]R<P`N:F-R`"YD871A+G)E
M;"YR;P`N9FEX=7``+F=O=#(`+F1Y;F%M:6,`+F=O=``N9&%T80`N<V1A=&$`
M+G-B<W,`+F)S<P`N8V]M;65N=```````````````````````````````````
M````````````````````````"P````$````"`8`!-````30````7````````
M```````!`````````!,````'`````@&``4P```%,````&```````````````
M!``````````F````!P````(!@`%D```!9````!0```````````````0`````
M````-P````4````"`8`!>````7@```*8````!0`````````$````!````#T`
M```+`````@&`!!````00```&$`````8````!````!````!````!%`````P``
M``(!@`H@```*(```!($```````````````$`````````30````0````"`8`.
MI```#J0```!4````!0`````````$````#````%<````$````0@&`#O@```[X
M```"]`````4````7````!`````P```!A`````0````8!@!'L```1[````"``
M``````````````0`````````9P````$````&`8`2$```$A```#B@````````
M```````0`````````&T````!````!@&`2K```$JP````(```````````````
M!`````````!S`````0````(!@$K0``!*T```/PP```````````````0`````
M````>P````$````"`8")W```B=P```#T```````````````$`````````(D`
M```!`````@&`BM```(K0```&\```````````````!`````````"3`````0``
M``,!@?Z$``#^A`````@```````````````0`````````F@````$````#`8'^
MC```_HP````(```````````````$`````````*$````!`````P&!_I0``/Z4
M````!```````````````!`````````"F`````0````,!@?Z8``#^F````!,`
M``````````````@`````````LP````$````#`8'^K```_JP````$````````
M```````$`````````+H````!`````P&!_K```/ZP````8```````````````
M!`````````#`````!@````,!@?\0``#_$````.`````&``````````0````(
M````R0````$````#`8'_\```__`````0```````````````$````!````%P`
M```!`````P&"`````0``````_```````````````!`````````#.`````0``
M``,!@@#\``$`_`````0```````````````0`````````U`````$````#`8(!
M```!`0`````(```````````````$`````````-L````(`````P&"`0@``0$(
M````$```````````````"`````````#A````"`````,!@@$8``$!"```!6P`
M``````````````@`````````Y@````$````P```````!`0@````[````````
M```````!`````0```!\````!`````````````0%#```!5@``````````````
M`0`````````!`````P````````````$"F0```.\```````````````$`````
